aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGravatar Tom Willemse2020-12-02 19:06:58 -0800
committerGravatar Tom Willemse2020-12-02 19:06:58 -0800
commitd4d4c75d62a1e67296e420c2099dc3c9d5b7fc9a (patch)
tree442d6358a1521a967864e76b807acb026a4b0e60
parent7969cd4251368706607fcaf887d00e0b720ef08a (diff)
downloademacs-config-d4d4c75d62a1e67296e420c2099dc3c9d5b7fc9a.tar.gz
emacs-config-d4d4c75d62a1e67296e420c2099dc3c9d5b7fc9a.zip
Add which-key mode
-rw-r--r--oni-core.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/oni-core.el b/oni-core.el
index 963bdb5..a7395a8 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2020.1113.093546
;; Package-Requires: (oni-data-dir oni-embrace expand-region multiple-cursors gcmh diminish ws-butler composable)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
(require 'oni-data-dir)
(require 'recentf)
(require 'ws-butler)
+(require 'which-key)
(defconst oni-core--auto-save-directory (oni-data-dir-locate "auto-save-files/")
"Directory where auto-saves go.")
@@ -162,6 +163,7 @@
(gcmh-mode)
(ws-butler-global-mode)
(composable-mode)
+(which-key-mode)
(add-to-list 'display-buffer-alist
`(,(rx string-start
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2020.1113.093546
-;; Package-Requires: (oni-data-dir oni-embrace expand-region multiple-cursors gcmh diminish ws-butler composable)
+;; Version: 2020.1202.190437
+;; Package-Requires: (oni-data-dir oni-embrace expand-region multiple-cursors gcmh diminish ws-butler composable which-key)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by